@@ -1,5 +1,5 @@
 import pytest
-from ..core.templates import project_templates
+from pymodularizer.core.templates import project_templates
 
 def test_project_types_have_description_and_structure():
     types = project_templates.get("project_types", {})
